package com.devsoap.json;

import org.junit.jupiter.api.Test;

import static com.devsoap.json.JsonAssert.assertThat;

public class ArrayTraversalAssertionTest {

    private static final String JSON = """
    {
        "array": [
          { "item": 1 },
          { "item": 2 }
        ],
    
        "numericArray": [
            1,2,3
        ],
    
        "fieldArray": {
          "array": [
             { "item": 3 },
             { "item": 4 }
          ],
          "numericArray": [
            1,2,3
          ]
        },
    
        "matrix": [
          [1,2],
          [3,4]
        ]
    }
    """;

    @Test
    public void rootArray() {
        assertThat(JSON)
                .array("array")
                .first()
                .field("item")
                .isEqualTo(1);

        assertThat(JSON)
                .array("array")
                .last()
                .field("item")
                .isEqualTo(2);
    }

    @Test
    public void fieldArray() {
        assertThat(JSON)
                .field("fieldArray")
                .array("array")
                .first()
                .field("item")
                .isEqualTo(3);

        assertThat(JSON)
                .field("fieldArray")
                .array("array")
                .last()
                .field("item")
                .isEqualTo(4);
    }

    @Test
    public void numericArray() {
        assertThat(JSON)
                .array("numericArray", Integer.class)
                .first()
                .isEqualTo(1);

        assertThat(JSON)
                .field("fieldArray")
                .array("numericArray", Integer.class)
                .first()
                .isEqualTo(1);
    }

    @Test
    public void matrix() {
        assertThat(JSON)
                .array("matrix")
                .first()
                .asArray()
                .first()
                .asInteger()
                .isEqualTo(1);

        assertThat(JSON)
                .array("matrix")
                .first()
                .asArray()
                .last()
                .asInteger()
                .isEqualTo(2);

        assertThat(JSON)
                .array("matrix")
                .last()
                .asArray()
                .first()
                .asInteger()
                .isEqualTo(3);

        assertThat(JSON)
                .array("matrix")
                .last()
                .asArray()
                .last()
                .asInteger()
                .isEqualTo(4);
    }
}