package com.devsoap.json;

import org.junit.jupiter.api.Test;

import java.math.BigDecimal;
import java.math.BigInteger;

import static com.devsoap.json.JsonAssert.assertThat;

public class StringAssertionTest {

    private static final String JSON = """
    {
      "foo": "bar",
      "number": "1234"
    }
    """;

    @Test
    public void equals() {
        assertThat(JSON)
                .field("foo")
                .isEqualTo("bar")
                .isNotEqualTo("baz");
    }

    @Test
    public void matches() {
        assertThat(JSON)
                .field("foo")
                .matches("b+a+r+")
                .notMatches("baz");
    }

    @Test
    public void stringToNumber() {
        assertThat(JSON)
                .field("number")
                .asInteger()
                .isEqualTo(1234);
        assertThat(JSON)
                .field("number")
                .asDouble()
                .isEqualTo(1234.0);
        assertThat(JSON)
                .field("number")
                .asLong()
                .isEqualTo(1234L);
        assertThat(JSON)
                .field("number")
                .asBigDecimal()
                .isEqualTo(BigDecimal.valueOf(1234.0));
        assertThat(JSON)
                .field("number")
                .asBigInteger()
                .isEqualTo(BigInteger.valueOf(1234));    }
}